﻿--[[---------------------------------------------------------------------------

The information the follow below is provided as-is and without warranty as a
guide for creating your own custom nUI6 Info Panel Plugin. Note that the nUI6
Info Panel Plugin API is subject to change at all times. However, if the custom
plugin you create adhears to the API outlined below, it should function with
nUI6 with no further ado. 

--]]---------------------------------------------------------------------------

if not nUI6.InfoPanels then nUI6.InfoPanels = {}; end
if not nUI6.InfoPanels.Plugins then nUI6.InfoPanels.Plugins = {}; end

-------------------------------------------------------------------------------
-- this can be either an empty table or a frame as you see fit. It is the 
-- base of your custom plugin and the mechanism through which your plugin
-- will present the nUI6 Info Panel Plugin Interface to the nUI6 Info Panel
-- management system. nUI6 will not directly modify anything in this table.
-- nUI will provide you with a secure frame you can anchor visbile elements
-- to as needed, or you can create your own frame here and then just anchor
-- it to the container that nUI6 provides. If you create your own frame, then
-- you should set the container passed in the SetContainer() method below to
-- be the parent of your custom frame.

local InfoPanelPlugin = {};

-------------------------------------------------------------------------------
-- this is the text name of your custom plugin. It mush be unique to the nUI6
-- data space (i.e. if another author has created a custom plugin, you cannot
-- use the same name for your plugin that they used for theirs.

local PanelName = "GuildChat";

-------------------------------------------------------------------------------
-- this line should not be changed. It's the hook that is used to tell nUI6
-- that your custom plugin is available for the user to attach to one of
-- the info panels defined in their nUI6 skin. If your custom plugin will
-- support more than one instance, then there should be one line here for
-- each instance you support, or you should add instances as required.

nUI6.InfoPanels.Plugins[PanelName] = InfoPanelPlugin;

-------------------------------------------------------------------------------
-- You can add any number of functions and variables of your own that you need 
-- to complete the plugin in this section... nUI6 will never call and of these 
-- custom functions directly, nor modify your plugin directly, other than by 
-- calling one of the functions listed in the nUI6 Info Panel Plugin Interface
-- defined below. 

local DefaultConfig =
{
	editBoxLocation = "BOTTOM",							-- can be "TOP", "BOTTOM", "ABOVE" or "BELOW"
	buttonsLocation = "INSIDE_RIGHT",					-- can be "INSIDE_LEFT", "INSIDE_RIGHT", "OUTSIDE_LEFT" or "OUTSIDE_RIGHT"
	buttonSpace     = -2,								-- vertical space between buttons
	buttonScale     = 1,								-- modify the scale of the chat frame buttons
	disableFade     = false,							-- set true to prevent chat buttons from fading
};

local pluginParent = nil;
local pluginState  = false;
local pending      = false;
local pluginConfig = nUI6.TableCopy( DefaultConfig );
local updateTimer  = math.floor(GetTime());
local plugin 	   = CreateFrame("Frame","nUI6_InfoPanel_GuildChat")

local addonName,addonData = ...
addonData = addonData or {}

local function UpdatePlugin()
	local guildName = GetGuildInfo("player");
	local gender = UnitSex("player");	
	local name, description, standingID, barMin, barMax, barValue, _, _, _, _, _, _, _ = GetGuildFactionInfo();	
	local factionStandingtext = GetText("FACTION_STANDING_LABEL"..standingID, gender);	
	local memberCount,onlineCount = GetNumGuildMembers();
	if (guildName) then
		addonData.windowName = format("%s (%s / %s) [%s]",guildName,onlineCount,memberCount,factionStandingtext);
	else
		addonData.windowName = format("%s",ERR_GUILD_PLAYER_NOT_IN_GUILD );
	end	
	FCF_SetWindowName(addonData.ChatFrame, addonData.windowName, 1);
end

local function SetWindowName()
	if ( not addonData.ChatFrame or not addonData.windowName ) then return end
	FCF_SetWindowName(addonData.ChatFrame, addonData.windowName);	
end

local function EnablePlugin(plugin)

	-- Unless of course we try to before the frame has been generated
	if ( not addonData.ChatFrame ) then return end

	if ( not addonData.ChatFrame.ipInitialised ) then UpdatePlugin() end

	if ( not addonData.windowName ) then 
		UpdatePlugin()
		if ( not addonData.windowName ) then 
			return 
		end
	end

	-- We're gonna re-parent so store the current parents
	plugin.chatlog_parent = addonData.ChatFrame:GetParent();
	plugin.chattab_parent = addonData.Tab:GetParent();

	-- If the frame/tab isn't shown then show them
	if not addonData.ChatFrame:IsShown() then
		addonData.ChatFrame:Show();
		addonData.Tab:Show();
		SetChatWindowShown(addonData.ChatFrame:GetID(), 1);
	end
	
	-- Start Moving/Sizing the frame
	MOVING_CHAT_FRAME = addonData.ChatFrame;

	-- Unlock the frame if it is locked
	FCF_SetLocked( addonData.ChatFrame, nil );
	
	-- Undock the frame if it is docked
	FCF_UnDockFrame( addonData.ChatFrame );

	addonData.ButtonFrame:SetParent(nil)
	addonData.ButtonFrame:ClearAllPoints()
	addonData.ButtonFrame:SetParent(addonData.ChatFrame)
	addonData.ButtonFrame:SetPoint("TOPRIGHT",pluginParent,"TOPRIGHT",0,0)
	addonData.ButtonFrame:SetPoint("BOTTOMRIGHT",pluginParent,"BOTTOMRIGHT",0,0)
	
	-- Carry out the actual Moving/Sizing of the chat frame
	addonData.ChatFrame:StartMoving();
	addonData.ChatFrame:StartSizing();
	addonData.ChatFrame:SetParent(nil);
	addonData.ChatFrame:ClearAllPoints();
	addonData.ChatFrame:SetParent( pluginParent );
	addonData.ChatFrame:SetPoint("TOPLEFT",pluginParent,"TOPLEFT",0,0);
	addonData.ChatFrame:SetPoint("BOTTOMRIGHT",addonData.ButtonFrame,"BOTTOMLEFT")

	-- Re-parent the chat tab and position it to the topleft of the chatframe
	addonData.Tab:SetParent(nil);
	addonData.Tab:ClearAllPoints();
	addonData.Tab:SetParent( addonData.ChatFrame );
	addonData.Tab:SetPoint("BOTTOMLEFT",addonData.ChatFrame, "TOPLEFT",0,0);
	addonData.Tab:Hide();

	-- Reset the background of the chatframe to cover the whole frame
	addonData.Background:ClearAllPoints();
	addonData.Background:SetAllPoints( addonData.ChatFrame );

	-- The store and nullify the reanchoring function for the background
	addonData.Background.cachedSetPoint = addonData.Background.SetPoint;
	addonData.Background.SetPoint       = function() end;

	

	addonData.ChatFrame:StopMovingOrSizing();
	
	-- Okay, we're finished moving stuff
	MOVING_CHAT_FRAME = nil;
	
	-- Set some required values for future use
	addonData.ChatFrame:SetMovable( true );
	addonData.ChatFrame:SetResizable( true );
	addonData.ChatFrame:SetClampedToScreen( false );
	addonData.ChatFrame:SetUserPlaced( true );
	
	-- Locked the frame and turn off the backdrop color
	FCF_SetLocked( addonData.ChatFrame, 1 );
	FCF_SetWindowAlpha( addonData.ChatFrame, 0 );

	if ( addonData.ChatFrame.ipInitialised ) then
		-- First Remove all channels and message groups
		ChatFrame_RemoveAllChannels( addonData.ChatFrame );
		ChatFrame_RemoveAllMessageGroups( addonData.ChatFrame );
		ChatFrame_ReceiveAllPrivateMessages( addonData.ChatFrame );
		ChatFrame_ReceiveAllBNConversations( addonData.ChatFrame );
	end
		
	-- Just in case Blizz overrode the tab text, restore the window name again
	SetWindowName();	

	-- Hide the minimize button as we shouldn't need to use it
	if ( addonData.MinimizeButton ) then RegisterStateDriver( addonData.MinimizeButton, "visibility", "hide" ); end
	
	-- Turn down the alpha setting of the other buttons
	addonData.BottomButton:SetAlpha( 0 );			
	addonData.DownButton:SetAlpha( 0 );			
	addonData.UpButton:SetAlpha( 0 );

	-- set method to show or hide the scroll buttons based on whether or
	-- not the mouse is in the frame
	
	addonData.ChatFrame.showButtons = function( enabled )		
		if enabled ~= addonData.ChatFrame.buttons_visible then					
			addonData.ChatFrame.buttons_visible = enabled;
			addonData.BottomButton:SetAlpha( enabled and 1 or 0 );
			addonData.DownButton:SetAlpha( enabled and 1 or 0 );
			addonData.UpButton:SetAlpha( enabled and 1 or 0 );				
		end
	end
	
	-- allow scrolling of the chat log frame with the mouse wheel	
	addonData.ChatFrame:EnableMouseWheel( true );	
	
	addonData.ChatFrame:SetScript( "OnMouseWheel", 
		function(self,arg1)
			if arg1 > 0 then self:ScrollUp();
			else self:ScrollDown();
			end	
		end
	);	

	-- Now that we're done here show the frame and tab
	addonData.ChatFrame:Show();
	addonData.Tab:Show();
	SetChatWindowShown(addonData.ChatFrame:GetID(), 1);
end

addonData.DisablePlugin = function(self,plugin)

	-- But if the frame doesn't exist it was never enabled *touch wood*
	if ( not addonData.ChatFrame ) then return end

	-- If we re-parented, which we should have, then put the parent back
	if plugin.chattab_parent then
		addonData.Tab:SetParent( plugin.chattab_parent );
		plugin.chattab_parent = nil;
	end

	-- If we re-parented the chatframe, and we definitely should have, then restore parent, re-dock, re-anchor
	if plugin.chatlog_parent then
		addonData.ChatFrame:SetParent( plugin.chatlog_parent );
		FCF_DockFrame( addonData.ChatFrame, #FCFDock_GetChatFrames(GENERAL_CHAT_DOCK)+1, true );
		plugin:SetScript( "OnUpdate", nil );
		plugin.chatlog_parent = nil;

		addonData.Background.SetPoint = addonData.Background.cachedSetPoint;
		addonData.Background:ClearAllPoints();
		addonData.Background:SetPoint( "TOPLEFT", addonData.ChatFrame, "TOPLEFT", -2, 3 );
		addonData.Background:SetPoint( "TOPRIGHT", addonData.ChatFrame, "TOPRIGHT", 2, 3 );
		addonData.Background:SetPoint( "BOTTOMLEFT", addonData.ChatFrame, "BOTTOMLEFT", -2, -6 );
		addonData.Background:SetPoint( "BOTTOMRIGHT", addonData.ChatFrame, "BOTTOMRIGHT", 3, -6 );
	end

	SetChatWindowShown(addonData.ChatFrame:GetID(),0)
	SetChatWindowName(addonData.ChatFrame:GetID(),"")
	SetChatWindowDocked(addonData.ChatFrame:GetID(),0)	
end


local function MouseOverPlugin(plugin)
	-- Reset the mouseover timer
	local mouseover_timer = 0;
	
	-- Set Up the OnUpdate routine for this panel to handle mouse over updates
	local function onUpdate( who, elapsed )			
	     mouseover_timer = mouseover_timer + elapsed;				
		 
		 -- Every 5 frames per second show the buttons ( if the frame exists ) and reset the timer
		 -- Also restore the name we want in the frame just in case Blizz overwrote it
	     if mouseover_timer > 0.2 then -- 5 fps is plenty fast enough to show these buttons				
	     	mouseover_timer = 0;				
		    if ( addonData.ChatFrame ) then addonData.ChatFrame.showButtons( MouseIsOver( addonData.ChatFrame ) );	 end
			UpdatePlugin()
	     end
    end                						
    plugin:SetScript( "OnUpdate", onUpdate );	
end

local function GetActiveChatFrames()
	local shownList = {};
	local dockedList = {};
	local infoPanelList = {};
	local count = 0;
	local chatFrame;
	
	-- Cycle through ChatFrames 1 to 10 ( the current NUM_CHAT_WINDOWS setting )
	for i=1, NUM_CHAT_WINDOWS do

		-- Get the chatFrame object for this possible frame
		chatFrame = _G["ChatFrame"..i];
	
		-- Is it supposed to be shown ?
		local _, _, _, _, _, _, shown = FCF_GetChatWindowInfo(i);
				
		-- ChatFrame should be valid but double check
		if ( chatFrame ) then
		
			-- If it is flagged as a shown window then add it to the shown list
			if ( shown ) then shownList[chatFrame:GetID()] = true; end
			
			-- If it is flagged as a docked window then add it to the docked list
			if ( chatFrame.isDocked ) then dockedList[chatFrame:GetID()] = true; end

			-- If an info panel is using it then we don't want to use it
			if ( chatFrame.infoPanel ) then infoPanelList[chatFrame:GetID()] = true; end
			
		end
	end
	
	-- return the lists for viewing later
	return shownList,dockedList,infoPanelList;
end

local function ExtractChatFrameElements()
	-- Of we aren't ready to initialise then don't activate the plugin quite yet
	if ( not addonData.ChatFrame ) then return end

	addonData.Tab  			= _G[addonData.ChatFrame:GetName().."Tab"];
	addonData.Background	= _G[addonData.ChatFrame:GetName().."Background"];
	addonData.ButtonFrame	= _G[addonData.ChatFrame:GetName().."ButtonFrame"];
	addonData.EditBox		= _G[addonData.ChatFrame:GetName().."EditBox"];

	addonData.MinimizeButton= _G[addonData.ButtonFrame:GetName().."MinimizeButton"];
	addonData.BottomButton	= _G[addonData.ButtonFrame:GetName().."BottomButton"];
	addonData.DownButton	= _G[addonData.ButtonFrame:GetName().."DownButton"];
	addonData.UpButton 		= _G[addonData.ButtonFrame:GetName().."UpButton"];
end

local function RestoreChatFrame(windowName)
	
	-- If we aren't ready to initialise then don't activate the plugin quite yet
	if ( not addonData.ChatFrame ) then return end

	-- Set the Window name which gets displayed on the tab
	addonData.windowName = windowName
	SetWindowName(addonData.windowName);

	-- Make sure we have shortcut variables for the chat frame parts
	ExtractChatFrameElements()
	
	addonData.ChatFrame.ipInitialised = false;
end

local function InitialiseChatFrame(windowName)
	
	-- If we aren't ready to initialise then don't activate the plugin quite yet
	if ( not addonData.ChatFrame ) then return end

	-- Extract elements of the frame
	ExtractChatFrameElements()

	-- Copy the settings from the default chat frame
	FCF_CopyChatSettings(addonData.ChatFrame, DEFAULT_CHAT_FRAME);

	-- Set the Window name which gets displayed on the tab
	SetWindowName();

	-- Clear any stale messages
	addonData.ChatFrame:Clear();

	addonData.ChatFrame.ipInitialised = true;
end

local function OnEvent(self,event,arg1,arg2,arg3)

	local guildUILoaded = guildUILoaded or false
	local pluginLoaded = pluginLoaded or false
	if ( event == "ADDON_LOADED") then 
		if ( arg1 == "Blizzard_GuildUI" ) then
			guildUILoaded = true
		end
			
	-- If we are using simple chat then we need to deactivate the addon
	elseif (event == "PLAYER_LOGIN") then
		plugin.IPLoggedIn		= true;
		
	-- If blizz is updating the chat windows then we want in so we can do our stuff
	elseif ( event == "UPDATE_CHAT_WINDOWS" ) then

		if ( shownList or dockedList or infoPanelList ) then return end

		-- Get the current list of frames
		local shownList,dockedList,infoPanelList = GetActiveChatFrames();
		
		-- A counter to see if there is a real reason for the plugin to not work
		local inUse = 0;
		
		-- Go through the list of available chat frames
		for i = 1, NUM_CHAT_WINDOWS do
		
			-- Generate a chat frame object
			local cf = _G["ChatFrame"..i];
			
			-- If it is not in the shown or docked list then it *should* be available for use
			if ( not shownList[cf:GetID()] and not dockedList[cf:GetID()] and not infoPanelList[cf:GetID()] ) then
			
				-- Set our special variable with the frame we're gonna use
				addonData.ChatFrame = _G["ChatFrame"..i];

				-- Tell us that we are using it in an infoPanel as that isn't docked or shown
				addonData.ChatFrame.infoPanel = true;
				
				-- Initialise the rest of its settings
				InitialiseChatFrame(addonData.windowName);
				
				-- Then Add the ones we want to track
				ChatFrame_AddMessageGroup(addonData.ChatFrame, "GUILD");
				ChatFrame_AddMessageGroup(addonData.ChatFrame, "OFFICER");
				ChatFrame_AddMessageGroup(addonData.ChatFrame, "GUILD_ACHIEVEMENT");
								
				
				-- Set the Window name which gets displayed on the tab
				SetWindowName();

				
				-- We made our frame so we can stop looking for a spot
				break;
			else
				-- Oops, can't use that frame add it to the count
				inUse = inUse + 1;
			end
		end
		
		-- Aww for shame, can't find a frame to use.
		-- If this is the first attempt to create a chat frame to use and one isn't available
		-- then display a message saying so.  Once this addon finds a free chat frame it will always use it
		-- until the WTF file is emptied
		if ( not addonData.ChatFrame ) then
			--DEFAULT_CHAT_FRAME:AddMessage(format(Translate["INUSE_FORMAT"],addonName,inUse), 1, 0.83, 0 );
			DEFAULT_CHAT_FRAME:AddMessage("Too many chat frames to create this one.", 1, 0.83, 0 );
			plugin.active = false;
			if ( plugin.IPLoggedIn ) then 
				UpdatePlugin()
				plugin.IPInitialised = false;
			end
		else			
			plugin.active = true;
			if ( plugin.IPLoggedIn ) then 
				plugin.IPInitialised = true;
			end
		end
		if ( not guildUILoaded ) then
			LoadAddOn("Blizzard_GuildUI")
		end
		
	-- As we log out disable the plugin so that we can recreate a new frame next time we log in
	elseif ( event == "PLAYER_LOGOUT" ) then
		if ( addonData.ChatFrame ) then 
			addonData:DisablePlugin(plugin)
			plugin.IPInitialised = false; 
		end
				
	elseif (event == "GUILD_INVITE_REQUEST") then
		GuildRoster();
		
	elseif (event == "GUILD_INVITE_CANCEL") then
		GuildRoster();
		
	elseif (event == "GUILD_XP_UPDATE" ) then
		SetWindowName();
	
	elseif (event == "PLAYER_GUILD_UPDATE") then
		if(math.floor(GetTime()) > updateTimer) then
			updateTimer = math.floor(GetTime());         	        
			SetWindowName();
		end
		
	elseif (event == "GUILD_ROSTER_UPDATE") then
		if(math.floor(GetTime()) > updateTimer) then
			updateTimer = math.floor(GetTime());         	        
			SetWindowName();
		end
		
	end	
	
end

plugin:SetScript( "OnEvent",OnEvent );
plugin:RegisterEvent( "PLAYER_LOGIN" );
plugin:RegisterEvent( "GUILD_INVITE_REQUEST" );
plugin:RegisterEvent( "GUILD_INVITE_CANCEL" );
plugin:RegisterEvent( "PLAYER_GUILD_UPDATE" );
plugin:RegisterEvent( "GUILD_XP_UPDATE" );
plugin:RegisterEvent( "GUILD_ROSTER_UPDATE" );
plugin:RegisterEvent( "UPDATE_CHAT_WINDOWS" );
plugin:RegisterEvent( "PLAYER_LOGOUT" );
plugin:RegisterEvent( "ADDON_LOADED" );



--#############################################################################
-- Everything below this point represents the required Info Panel Plugin 
-- Interface. Your custom plugin has to provide each of these functions. You
-- should complete each with the code and values that are appropriate to the
-- function as each function has been described. You should complete every
-- one of these functions even if you don't need it internally by giving it a 
-- default empty behavior. 
--#############################################################################

-------------------------------------------------------------------------------
-- This method just allows the nUI6 Info Panel system to get the name of the
-- the plugin from the plugin object itself. It should not normally need to
-- be modified from the default implementation unless your plugin is going to
-- support more than one instance, in which case each instance must have a
-- unique name and you should return the appropriate name for the referenced
-- instance indicated by "who"
--
-- arguments:	who			-- which info panel plugin instance is being queried
--
-- returns:		string		-- the name of your custom plugin
-------------------------------------------------------------------------------

InfoPanelPlugin.GetPluginName = function( who )
	return PanelName;
end

-------------------------------------------------------------------------------
-- This method is called any time the container this plugin is managed by
-- is shown or hidden in the info panel the user has assigned the plugin to
--
-- arguments:	who			-- the info panel instance being shown/hidden
--				state		-- true when shown, false when hidden
--
-- returns:		none
-------------------------------------------------------------------------------

InfoPanelPlugin.ShowPlugin = function( who, state )
	
	if ( not addonData.ChatFrame ) then return end

	-- If not being shown, no need to update
	if ( not state  ) then 
		-- Turn off the Update routine when not selected
		addonData.ChatFrame:SetScript( "OnUpdate", nil );			
		return 
	end
	MouseOverPlugin(addonData.ChatFrame)
	UpdatePlugin()
end

-------------------------------------------------------------------------------
-- This method is called any time the user enables or disables the plugin. The
-- plugin may or may not have been, or be, displayed when this method is called
-- and it is presumed that when disabled the plugin does not alter the UI or
-- has undone whatever modifications it made to the UI. A plugin should always 
-- presume that it is, and behave as though it were, disabled unless and until 
-- this method is called. A plugin should not assume that it is active until 
-- it is actually enabled by a call to this method and should not modify the 
-- UI or take other action until that time.
--
-- arguments:	who			-- the info panel plugin instance being enabled/disabled
--				state		-- true when enabled, false when disabled
--
-- returns:		none
-------------------------------------------------------------------------------

InfoPanelPlugin.EnablePlugin = function( who, state )

	-- If we were unable to choose a chat frame then no need to continue
	if ( not addonData.ChatFrame ) then return end

	-- check state
	if state ~= isEnabled and pluginParent then	
		pluginState = state;
		if ( state ) then

			-- Set the fancy stuff
			EnablePlugin(who)

			-- Then Add the ones we want to track
			ChatFrame_AddMessageGroup(addonData.ChatFrame, "GUILD");
			ChatFrame_AddMessageGroup(addonData.ChatFrame, "OFFICER");
			ChatFrame_AddMessageGroup(addonData.ChatFrame, "GUILD_ACHIEVEMENT");
			
			-- Just in case Blizz overrode the tab text, restore the window name again
			SetWindowName()
		else

			-- unset the fancy stuff
			addonData:DisablePlugin(who)

			-- This little monster makes sure that we restore the chat settings to the general chat frame and closes the frame
			FCF_PopInWindow(addonData.ChatFrame);		
		end
	else
		pending = state ~= isEnabled and state or false;
	end
end

-------------------------------------------------------------------------------
-- The user may, potentially, move a plugin from one info panel to another, or
-- resize an info panel at any time (out of combat). This method will be called
-- any time the size of the container that manages the plugin changes. 
--
-- arguments:	who			-- the info panel plugin instance being resized
--				width		-- the new width of the info panel's container
--				height		-- the new height of the info panel's container
--
-- returns:		none
-------------------------------------------------------------------------------

InfoPanelPlugin.ResizePlugin = function( who, width, height )

	if ( not addonData.ChatFrame ) then return end

	FCF_SetLocked( addonData.ChatFrame, 0 );
	addonData.ChatFrame:StartMoving();
	addonData.ChatFrame:StartSizing();
	addonData.ChatFrame:ClearAllPoints();
	addonData.ChatFrame:SetWidth( width / addonData.ChatFrame:GetScale() );
	addonData.ChatFrame:SetHeight( height / addonData.ChatFrame:GetScale() );

	addonData.ChatFrame:SetPoint( "TOPLEFT", pluginParent, "TOPLEFT", 0, 0 );
	addonData.ChatFrame:SetPoint( "BOTTOMRIGHT", pluginParent, "BOTTOMRIGHT", 0, 0 );

	-- stop sizing and positioning the chat frame				
	FCF_SetLocked( addonData.ChatFrame, 1 );
	FCF_SetWindowAlpha( addonData.ChatFrame, 0 );
	addonData.ChatFrame:StopMovingOrSizing();


end

-------------------------------------------------------------------------------
-- This method is called by the info panel system prior to player logout to 
-- collect the plugin's current configuration data and to write it to the nUI6
-- saved variables file
--
-- arguments:	who			-- the info panel plugin instance being queried
--
-- returns:		table		-- a table containing the configuration data for
--							   the plugin. It should contain key/value pairs
--							   for each configuration item the plugin uses or
--							   return nil if there is no configuration data
--							   associated with the plugin
-------------------------------------------------------------------------------

InfoPanelPlugin.GetConfig = function( who )
	return nUI6.TableCopy( pluginConfig );
end

-------------------------------------------------------------------------------
-- This method is called by the info panel system when a plugin is initially
-- loaded to allow the plugin to configure itself with the data that has been
-- saved in the user's saved variables. The plugin should presume that it has
-- not yet been displayed when this call is made. If there is data in the 
-- user's saved variables for this plugin, it will be passed. If there's no
-- data in the user's saved variables for this plugin, it will pass nil
--
-- arguments:	who			-- the info panel plugin to be configured
--				config		-- the config data table or nil
--
-- returns:		none
-------------------------------------------------------------------------------

InfoPanelPlugin.SetConfig = function( who, config )	
	wipe( pluginConfig );	
	pluginConfig = nUI6.TableCopy( DefaultConfig );
end

-------------------------------------------------------------------------------
-- When the plugin is first added to the info panel, a container is created
-- for it by the info panel system. The container will be a frame build with
-- the "SecureFrameTemplate" type. The plugin should use this container as the
-- parent for all of its displayable elements and should respect the show/hide
-- state of the container. It should also respect the boundaries of the 
-- container... as long as all of the UI display elements for the plugin are
-- located within the bounds of the container, they will not overlap other
-- UI elements. The plugin should presume that the container is not yet visible
-- when it is first assigned and may change size at any time though the size
-- should be reasonably correct when this method is called.
--
-- The plugin should also respect the secure nature of the container and not
-- make modifications to is, assign values to it, etc., unless absolutely
-- necessary and, when it does, it should be sure to do it in a taint free way
-- (I would argue there's never a reason to modify the container). Likewise,
-- a plugin should never show/hide its container, change the anchor points of
-- the container or modify the size of the container.
--
-- arguments:	who			-- the info panel plugin instance been assigned
--				container	-- a reference to the plugin's parent secure frame
--
-- returns:		none
-------------------------------------------------------------------------------

InfoPanelPlugin.SetContainer = function( who, container )

	pluginParent = container;
	
	if pending then
		InfoPanelPlugin.EnablePlugin( who, pending );
		pending = false;
	end
end

-------------------------------------------------------------------------------
-- nUI6 defines two default Info Panel positions in the standard skin... these
-- are "LEFT" and "RIGHT" indicating the info panel at the lower left of the
-- user's dashboard (the one with the default chat frame in it) and the other
-- being the info panel at the lower right of the dashboard (the one with the
-- zone map in it). nUI6 also defines a "NONE" position meaning that the plugin
-- is not shown in any info panel. Custom skins may also define custom info
-- panel positions. This method is called by the info panel system when first
-- setting up the plugin to allow the plugin to specify which info panel it 
-- would prefer to be located in *if* the user has not assigned it to a 
-- specific info panel. This function will not be called if the user has 
-- assigned the plugin to a specific info panel. 
--
-- arguments:	who			-- which info panel plugin instance is being queried
--
-- returns:		string		-- the name of the preferred location for this 
--							   plugin instance. One of "LEFT", "RIGHT", "NONE"
--							   or a custom info panel position. If this method
--							   returns nil, then the plugin will be assigned to
--							   whatever the "default" info panel is for the 
--							   current skin.
-------------------------------------------------------------------------------

InfoPanelPlugin.PreferredPosition = function( who )
	return "RIGHT"
end

-------------------------------------------------------------------------------
-- This method is called by the info panel system to get a text string to be
-- displayed on the info panel's control button when this plugin is set active.
-- It should be a short text string that will fit inside a button and is user
-- friendly. Where applicable, the plugin should use GetLocale() to determine
-- the current user language and return the button label string in the correct
-- language for the user.
--
-- arguments:	who			-- which info panel plugin instance is being queried
--
-- returns:		string		-- a human friendly test string in the appropriate
--							   language and suitable for display on a button
-------------------------------------------------------------------------------

InfoPanelPlugin.GetButtonLabel = function( who )
	return "GuildChat"
end

-------------------------------------------------------------------------------
-- This method is called by the info panel system to build a user friendly list
-- of all of the plugins assigned to the info panel. It should be a short text
-- string suitable for display as a single line in a tooltip or menu. Where
-- applicable, the plugin should use GetLocale() to determine the current user
-- language and return the panel name string in the correct language.

-- arguments:	who			-- which info panel plugin instance is being queried
--
-- returns:		string		-- a human friendly test string in the appropriate
--							   language and suitable for display on a list of
--							   plugins associated with a given info panel
-------------------------------------------------------------------------------

InfoPanelPlugin.GetPanelName = function( who )
	return addonData.windowName or "Guild Chat"
end

-------------------------------------------------------------------------------
-- This method is called by the info panel configuration system when the user
-- is setting up their info panels, assigning plugins to panels and enabling or
-- disabling their info panel plugins. It should use GetLocale() to fetch the
-- user's preferred language and return a text string suitable for display in
-- the "Interface > AddOns" configuration screen in WoW. It shouldn't be a book
-- but is otherwise free-form. The only requirement would be that it fit in the
-- space provided for it in the configuration screens.
--
-- arguments:	who			-- which info panel plugin instance is being queried
--
-- returns:		string		-- a text string in the user's language and
--							   suitable for display in the addon configuraiton
--							   screen
-------------------------------------------------------------------------------

InfoPanelPlugin.GetPluginDescription = function( who )
	return "A guild specific chat frame."
end

-------------------------------------------------------------------------------
-- This method is called by the info panel system when setting up the info
-- panel configuration options. It should return a reference to a frame that
-- is suitable for display in the "Interface > AddOns" configuraiton window.
-- It will be configured as a sub-category of the nUI6 Info Panels config.
-- If the plugin does not have configuration options, or does not need to be
-- configured, this method should return nil. The plugin's button name returned
-- from GetButtonLabel() will be used as the category name for the panel. You 
-- do not need to hook this window to the WoW Interface AddOns system yourself, 
-- nUI6 will do that for you ensuring that your plugin is listed in the correct 
-- category and the other generic options for the user to control the location 
-- and such are provided. Likewise, your custom config screen does not need to 
-- worry about which info panel the plugin is loaded in or whether or not your 
-- plugin is enabled. That is handled by the nUI6 Info Panel system.
--
-- See: http://www.wowwiki.com/Creating_GUI_configuration_options
--
-- arguments:	who			-- which info panel plugin instance is being queried
--
-- returns:		frame		-- a frame for use in the "Interface > AddOns"
--							   configuration window in WoW, or nil
-------------------------------------------------------------------------------

InfoPanelPlugin.GetConfigurationScreen = function( who )
	return nil
end

-------------------------------------------------------------------------------
-- This method is used to determine what nUI6 Info Panel API your custom
-- plugin adhears to. This will allow nUI6 to continue to support info panel
-- custom plugins for older versions if/when newer Info Panel functionality
-- is added in the future. In general, you should populate this return value
-- with whatever the current version of nUI6 was at the time that this plugin
-- was last updated.
--
-- arguments:	who			-- which info panel plugin instance is being queried
--
-- returns:		string		-- the nUI6 version this plugin was written to
-------------------------------------------------------------------------------

InfoPanelPlugin.GetPluginAPI = function( who )
	return "6.05.01.00.01";
end
